<?php 
ini_set('display_errors','On');
require_once($_SERVER['DOCUMENT_ROOT'].'/shine/datos/clsQuery.php');
	class clsUsuario extends Query 
	{
		var $filas = NULL;
		function __construct()  
		{
			parent::__construct();
			parent::MET_Conectar();
		}      
		/*
		function MET_verificarclave($identificacion, $clave_anterior)  {
			$sql = "
				SELECT 
				  1 as verificado
				FROM
				  M_PERFIL a 
				WHERE a.num_identificacion = \'$identificacion\' 
				AND md5(upper(trim(\'$clave_anterior\'))) = nom_clave
			";
				//	echo $sql;exit;
			parent::__set('sql', $sql);
			$registros = parent::MET_SelectOne();
              //          print_r($registros);exit;
			return $registros;
		} // end MET_consultaLibro	
*/

		function MET_existeusuario($usuario, $clave, $ip)  {
			$sql = "
				SELECT 
				  tip_cambiar, \'\'::text as razon_social
				FROM
				  M_USUARIO
				WHERE cod_cia = \'$usuario\' 
				AND md5(upper(trim(\'$clave\'))) = nom_clave
				and est_usuario=\'A\' 
			";
					echo $sql;exit;
			parent::__set('sql', $sql);
			$respuesta = parent::MET_SelectOne();
			
			if($respuesta){
				$sql1 = "
				select case when exists (select true from
				general.m_personaidentificacion
				where num_identificacion=\'".$usuario."\')
				then
				(select coalesce(a.primer_apellido,\'\')||\' \'||
				coalesce(a.segundo_apellido,\'\')||\' \'||
				coalesce(a.primer_nombre,\'\')||\' \'||
				coalesce(a.segundo_nombre,\'\') 
				from general.m_persona a,
				general.m_personaidentificacion b
				where a.id_persona=b.id_persona
				and b.num_identificacion=\'".$usuario."\')
				else
				(select nombre_comercial from
				general.m_personajuridica
				where num_ruc=\'".$usuario."\')
				end as persona;
				";
				//echo $sql1;exit;
				
				parent::__set('sql', $sql1);
				$respuesta2 = parent::MET_SelectOne();
				
			}
			
			if($respuesta2){
				$respuesta['razon_social']=$respuesta2['persona'];
				//print_r($respuesta);exit;
			}
			
			//$respuesta = MET_verificarclave($identificacion, $clave_anterior);
			if(!($respuesta['razon_social']=='')){
				
				$sql = "
				INSERT INTO facturacion.t_auditoriaconexiones (num_identificacion, fec_dia, nom_ip)
				values	(\'$usuario\'::text, now(), \'$ip\'::text)
				";
			//			echo $sql;exit;
				parent::__set('sql', $sql);
				$a = parent::MET_Insert();
				//return $a;
			
				return $respuesta;
			}else{
				return false;
			}
			
		} // end MET_consultaLibro	


		function MET_clavenueva($identificacion, $clave_anterior, $clave_nueva, $clave_confirma)  {
			if(!(strtoupper($clave_nueva)==strtoupper($clave_confirma))){
				return false;
			}
			if((strtoupper($clave_nueva)==strtoupper($clave_anterior))){
				return false;
			}
			$sql = "
				SELECT 
				  1 as verificado
				FROM
				  facturacion.m_perfilweb a 
				WHERE a.num_identificacion = \'$identificacion\' 
				AND md5(upper(trim(\'$clave_anterior\'))) = nom_clave
			";
				//	echo $sql;exit;
			parent::__set('sql', $sql);
			$respuesta = parent::MET_SelectOne();
			//print_r($respuesta);exit;
			//$respuesta = MET_verificarclave($identificacion, $clave_anterior);
			if(!($respuesta['verificado']==1)){
				return false;
			}
			$sql = "UPDATE facturacion.m_perfilweb SET NOM_CLAVE = md5(upper(trim(\'$clave_nueva\'))), tip_cambiar = 0
				  where num_identificacion = \'$identificacion\' 
				  AND md5(upper(trim(\'$clave_anterior\'))) = nom_clave
			";
					//echo $sql;exit;
			parent::__set('sql', $sql);
			$a = parent::MET_Update();
			//print_r($a);exit;
			return $a;
		} // end MET_consultaLibro	
		
		/*function MET_modificarperfil($identificacion, $direccion, $email, $celular, $telefono)  {
			$sql = "UPDATE M_PERFIL SET nom_direccion = \'$direccion\' ,
					nom_email = \'$email\' ,
					num_celular = \'$celular\' ,
					num_telefono = \'$telefono\' 
				  where num_identificacion = \'$identificacion\' 
			";
				//	echo $sql;exit;
			parent::__set('sql', $sql);
			$a = parent::MET_Update();
			return $a;
		} // end MET_consultaLibro	
		*/
		function MET_consultarPerfil($identificacion)  {
			$sql = "
				SELECT 
				  razon_social,
				  nom_direccion,
				  nom_email,
				  num_celular,
				  num_telefono
				FROM
				  facturacion.m_perfilweb a 
				WHERE a.num_identificacion = \'$identificacion\'
			";
				//	echo $sql;exit;
			parent::__set('sql', $sql);
			$registros = parent::MET_SelectOne();
              //          print_r($registros);exit;
			return $registros;
		} // end MET_consultaLibro		

			
     
	 function MET_consultaConexiones($identificacion)  {
			$sql = "
				SELECT 
				  date(fec_dia) AS fecha,
				  fec_dia::time::varchar(8) AS hora,
				  nom_ip AS ip
				FROM
				  facturacion.t_auditoriaconexiones 
				WHERE num_identificacion = \'$identificacion\' 
				ORDER BY 1,
				  2,
				  3 
			
			";
		//	$sql = mysql_escape_string($sql);
		//			echo $sql;exit;
			parent::__set('sql', $sql);
			$registros = parent::MET_Select();
//                        print_r($registros);exit;
			return $registros;
		} // end MET_consultaLibro
	
	function MET_fillTable($identificacion)  {
			$registros = $this->MET_consultaConexiones($identificacion);
			if (!$registros) 
			{
			$this->filas = '<tr> 
    		<td><div align="center" colspan="5"> '.$this->msj_query.'</div></td>
    				</tr>';	
			}
			else
			{
			foreach($registros as $ind => $reg) 
				{
				$this->filas .=	'
				<tr>
				<td>'.$reg['fecha'].'</td>
				<td>'.$reg['hora'].'</td>
				<td>'.$reg['ip'].'</td>
  				</tr>
				';	
				} //end foreach
			}//end if
			return $this->filas;			
		} // end MET_fillCombo*/	
	 
	}//end class
?>
